@@ -24,6 +24,8 @@
 #' @param pfac.base.covs a single value, or a vector of values, indicating
 #' whether the baseline covariates (if any) should be penalized (1) or not (0).
 #' Default is \code{pfac.base.covs = 0} (no penalization of all baseline covariates)
+#' @param cv.seed value of the random seed to use for the cross-validation
+#' done to select the optimal value of the tuning parameter
 #' @param n.alpha.elnet number of alpha values for the two-dimensional 
 #' grid of tuning parameteres in elasticnet.
 #' Only relevant if \code{penalty = 'elasticnet'}. Default is 11,
@@ -43,6 +45,8 @@
 #' \item \code{call}: the function call
 #' \item \code{pcox.orig}: the penalized Cox model fitted on the
 #' original dataset;
+#' \item \code{tuning}: the values of the tuning parameter(s) selected through 
+#' cross-validation
 #' \item \code{surv.data}: the supplied survival data (ordered by
 #' subject id)
 #' \item \code{n.boots}: number of bootstrap samples;
@@ -125,10 +129,11 @@
 fit_prcmlpmm = function(object, surv.data, baseline.covs = NULL,
                       include.b0s = TRUE,
                       penalty = 'ridge', standardize = TRUE,
-                      pfac.base.covs = 0,
+                      pfac.base.covs = 0, cv.seed = 19920207,
                       n.alpha.elnet = 11, n.folds.elnet = 5,
                       n.cores = 1, verbose = TRUE) {
   call = match.call()
+  penalty = match.arg(penalty, choices = c('ridge', 'elasticnet', 'lasso'))
   # remove b0s if include.b0s = F
   if (!include.b0s) {
     pos.b0 = which(substr(names(object$ranef.orig), 1, 2) == 'b0')
@@ -154,7 +159,8 @@ fit_prcmlpmm = function(object, surv.data, baseline.covs = NULL,
   out = fit_prclmm(object = object, surv.data = surv.data, 
                    baseline.covs = baseline.covs, 
                    penalty = penalty, standardize = standardize, 
-                   pfac.base.covs = pfac.base.covs, 
+                   pfac.base.covs = pfac.base.covs,
+                   cv.seed = cv.seed,
                    n.alpha.elnet = n.alpha.elnet,
                    n.folds.elnet = n.folds.elnet, 
                    n.cores = n.cores, verbose = verbose)
