@@ -34,6 +34,8 @@ print.sprclmm = function(x, digits = 4, ...) {
   dat = x$data_info
   paste('Fitted model:', mod$fitted_model) |> cat(); cat('\n')
   paste('Penalty function used:', mod$penalty) |> cat(); cat('\n')
+  paste('Tuning parameters:') |> cat(); cat('\n')
+  print(x$tuning)
   
   paste('Sample size:', dat$n) |> cat(); cat('\n')
   paste('Number of events:', dat$n_ev) |> cat(); cat('\n')
@@ -62,6 +64,7 @@ getinfo_step3 = function(x) {
     as.matrix() |> t()
   out = list(model_info = model_info, 
              data_info = data_info, 
-             coefficients = coefficients)
+             coefficients = coefficients,
+             tuning = x$tuning)
   out
 }
